pub struct Multisig {
pub owners: Vec<Pubkey>,
pub threshold: u64,
pub nonce: u8,
pub owner_set_seqno: u32,
}Fields
owners: Vec<Pubkey>threshold: u64nonce: u8owner_set_seqno: u32Trait Implementations
Sourceimpl AccountDeserialize for Multisig
impl AccountDeserialize for Multisig
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Multisig
impl AccountSerialize for Multisig
Sourceimpl BorshDeserialize for Multisigwhere
Vec<Pubkey>: BorshDeserialize,
u64: BorshDeserialize,
u8: BorshDeserialize,
u32: BorshDeserialize,
impl BorshDeserialize for Multisigwhere
Vec<Pubkey>: BorshDeserialize,
u64: BorshDeserialize,
u8: BorshDeserialize,
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Multisig
impl BorshSerialize for Multisig
Sourceimpl Discriminator for Multisig
impl Discriminator for Multisig
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]