pub struct Transaction {
pub multisig: Pubkey,
pub instructions: Vec<TransactionInstruction>,
pub signers: Vec<bool>,
pub owner_set_seqno: u32,
pub transaction_nonce: u64,
}Fields
multisig: Pubkeyinstructions: Vec<TransactionInstruction>signers: Vec<bool>owner_set_seqno: u32transaction_nonce: u64Trait Implementations
Sourceimpl AccountDeserialize for Transaction
impl AccountDeserialize for Transaction
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Transaction
impl AccountSerialize for Transaction
Sourceimpl BorshDeserialize for Transaction
impl BorshDeserialize for Transaction
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Transactionwhere
Pubkey: BorshSerialize,
Vec<TransactionInstruction>: BorshSerialize,
Vec<bool>: BorshSerialize,
u32: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for Transactionwhere
Pubkey: BorshSerialize,
Vec<TransactionInstruction>: BorshSerialize,
Vec<bool>: BorshSerialize,
u32: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Clone for Transaction
impl Clone for Transaction
Sourcefn clone(&self) -> Transaction
fn clone(&self) -> Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for Transaction
impl Discriminator for Transaction
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]