pub struct TransactionInstruction {
pub program_id: Pubkey,
pub accounts: Vec<TransactionAccount>,
pub data: Vec<u8>,
}Fields
program_id: PubkeyPubkey of the program that executes this instruction.
accounts: Vec<TransactionAccount>Metadata describing accounts that should be passed to the program.
data: Vec<u8>Opaque data passed to the program for its own interpretation.